@@ -16,12 +16,37 @@
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Menu bar opacity</source>
+        <translation>Opacité de la barre de menu</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>You must give name for the theme.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Folder </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source> already exists!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="0"/>
+        <source>Saving new theme...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="0"/>
+        <source>Save as new theme</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Restarting services, your screen will blink! Rebooting the device is recommended to reload all new values.</source>
-        <translation type="unfinished"></translation>
+        <translation>Redémarage des services, l&apos;écran va glignoter!Je vous recommande de redémarer le mobile pour recharger toutes les nouvelles valeurs.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="0"/>
@@ -420,17 +445,17 @@ déverrouillage</translation>
     <message>
         <location filename="backgrounds.cpp" line="0"/>
         <source>Select image</source>
-        <translation type="unfinished"></translation>
+        <translation>Sélectionne l&apos;image</translation>
     </message>
     <message>
         <location filename="backgrounds.cpp" line="0"/>
         <source>Processing image</source>
-        <translation type="unfinished"></translation>
+        <translation>Traitement de l&apos;image</translation>
     </message>
     <message>
         <location filename="backgrounds.cpp" line="0"/>
         <source>Image saved!</source>
-        <translation type="unfinished"></translation>
+        <translation>Image sauvegardée!</translation>
     </message>
 </context>
 <context>
@@ -484,4 +509,17 @@ déverrouillage</translation>
         <translation>Couleur originale du thème actuel</translation>
     </message>
 </context>
+<context>
+    <name>savenewtheme</name>
+    <message>
+        <location filename="savenewtheme.ui" line="0"/>
+        <source>Save theme as...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="savenewtheme.ui" line="0"/>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
